"use strict";
var fs = require("fs");
var express = require('express');

var app = express();

var port = process.env.PORT || 8080;

var env         = process.env.NODE_ENV || "dev";
var config      = require("./components/config/server." + env + ".js");

//initialize logging
app.set('winston', require('winston'));
var winston = app.get('winston');
require('./components/config/logging')(winston);
var logger = winston.loggers.get('default');

app.listen(port, '0.0.0.0');
logger.info("Fresenius Integration API Server started on port " + port);

if (config && config.receipts) {
    if (config.receipts.outDir && config.receipts.outDir !== "") {
        if (!fs.existsSync(config.receipts.outDir)) {
            var msg = "Receipts Outbound Directory does not exist!!!";
            console.error(msg);
            logger.error(msg);
            process.exit(1);
        }
    }
}

//initialize connections to the MQ framework
if (config.mqs && config.mqs === "rabbit") {
    var Rabbit = require("./components/helpers/RabbitHelper");
    app.set("mqs", new Rabbit(winston, config));
} else if (config.mqs && config.mqs === "sqs") {
    var SquissHelper = require("./components/helpers/SqsHelper");
    app.set("mqs", new SquissHelper(winston, config));
} else {
    var NullMqsHelper = require("./components/helpers/NullMqsHelper");
    app.set("mqs", new NullMqsHelper());
}

//initialize express
require('./components/config/express')(app, config);

module.exports = app;
